OC.L10N.register(
    "core",
    {
    "Sunday" : "ఆదివారం",
    "Monday" : "సోమవారం",
    "Tuesday" : "మంగళవారం",
    "Wednesday" : "బుధవారం",
    "Thursday" : "గురువారం",
    "Friday" : "శుక్రవారం",
    "Saturday" : "శనివారం",
    "January" : "జనవరి",
    "February" : "ఫిబ్రవరి",
    "March" : "మార్చి",
    "April" : "ఏప్రిల్",
    "May" : "మే",
    "June" : "జూన్",
    "July" : "జూలై",
    "August" : "ఆగస్ట్",
    "September" : "సెప్టెంబర్",
    "October" : "అక్టోబర్",
    "November" : "నవంబర్",
    "December" : "డిసెంబర్",
    "Settings" : "అమరికలు",
    "seconds ago" : "క్షణాల క్రితం",
    "No" : "కాదు",
    "Yes" : "అవును",
    "Ok" : "సరే",
    "Cancel" : "రద్దుచేయి",
    "Continue" : "కొనసాగించు",
    "Error" : "పొరపాటు",
    "Expiration date" : "కాలం చెల్లు తేదీ",
    "Password" : "సంకేతపదం",
    "Name" : "పేరు",
    "Save" : "భద్రపరచు",
    "delete" : "తొలగించు",
    "Warning" : "హెచ్చరిక",
    "Delete" : "తొలగించు",
    "Add" : "చేర్చు",
    "Personal" : "వ్యక్తిగతం",
    "Users" : "వాడుకరులు",
    "Help" : "సహాయం",
    "Username" : "వాడుకరి పేరు",
    "Log out" : "నిష్క్రమించు",
    "New password" : "కొత్త సంకేతపదం"
},
"nplurals=2; plural=(n != 1);");
